export * from './internal/module';
import { ChainedPod, StateResetAction } from './internal/interfaces';
import { reduxPodEnhancer } from './internal/enhancer';
export interface RootPodCreator {
    /**
     * Root pod creator function.
     *
     * @interface S The shape of the pod's reducer state.
     *
     * @param initialState The initial state of the pod reducer.
     */
    <S>(initialState: S): RootPod<S, {}>;
    /**
     * Root pod creator function w/ a state reset action key.
     *
     * @interface S The shape of the pod's reducer state.
     *
     * @param initialState The initial state of the pod reducer.
     * @param stateResetActionKey The key of the state reset action.
     */
    <S, A>(initialState: S, stateResetActionKey: keyof A): RootPod<S, A>;
    /**
     * Enhancer function to be included in the redux store creation.
     */
    enhancer: typeof reduxPodEnhancer;
}
/**
 * An alias type for a `ChainedPod` for applying the statereset action key.
 *
 * @interface S The state shape
 * @interface A The initial action obj. to map
 */
export declare type RootPod<S, A> = ChainedPod<S, {
    [ResetKey in keyof A]: StateResetAction;
}>;
/**
 * The root pod creator function overload handler.
 *
 * @param initialState The initial reducer state obj.
 * @param stateResetActionKey The state reset action key.
 */
export declare const rootPodCreator: RootPodCreator;
export default rootPodCreator;
